==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/outer.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//A HREF TAGS (links)
$lang['href_about'] =							"about around-me";
$lang['href_contributors'] =					"contributors";
$lang['href_help'] =							"lost?";
$lang['href_logoff'] =							"logoff";
$lang['href_selection'] = 						"Splash";
$lang['href_messages'] =						"Messages";
$lang['href_me'] =								"Me";
$lang['href_worldwide'] =						"worldwide";
$lang['href_shoutbox'] =						"shout!";
$lang['href_network'] = 						"Network";
$lang['href_groups'] = 							"Groups";
$lang['href_schedule'] = 						"Events";
$lang['href_node_admin'] = 						"administration";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_node_structure'] = 					"structure";
$lang['href_node_feedback'] = 					"feedback";
$lang['href_advanced_search'] = 				"advanced search";
$lang['href_information'] = 					"?";
$lang['href_search'] = 							"search";


// MENU
$lang['menu_events'] = 							"find events to attend";
$lang['menu_tasks'] = 							"find stuff to do";
$lang['menu_schedule'] = 						"my schedule";


//META TAGS (this will appear in search engines like google)
$lang['meta_Description'] =						""; //add in a description for your node
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (barnraiser, nodeX, place)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


//BODY TEXT
$lang['txt_page_title'] = 						"barnraiser &#47; aroundme &#47; demo";
$lang['txt_groups'] = 							"groups";
$lang['txt_messaging'] = 						"messaging";
$lang['txt_splash'] = 							"splash";
$lang['txt_me'] = 								"me";
$lang['txt_sn'] = 								"social network";
$lang['txt_schedule'] = 						"events and tasks";
$lang['txt_print_view'] = 						"print version";
$lang['txt_print_view_comments'] = 				"print version (with comments)";
$lang['txt_strap'] = 							"This <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and further society through social software. Please consider supporting us.";

?>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/outer.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//A HREF TAGS (links)
$lang['href_about'] =							"about around-me";
$lang['href_contributors'] =					"contributors";
$lang['href_help'] =							"lost?";
$lang['href_logoff'] =							"logoff";
$lang['href_selection'] = 						"Splash";
$lang['href_messages'] =						"Messages";
$lang['href_me'] =								"Me";
$lang['href_worldwide'] =						"worldwide";
$lang['href_shoutbox'] =						"shout!";
$lang['href_network'] = 						"Network";
$lang['href_groups'] = 							"Groups";
$lang['href_schedule'] = 						"Events";
$lang['href_node_admin'] = 						"administration";
$lang['href_report_abuse'] = 					"report abuse";
$lang['href_node_structure'] = 					"structure";
$lang['href_node_feedback'] = 					"feedback";
$lang['href_advanced_search'] = 				"advanced search";
$lang['href_information'] = 					"?";
$lang['href_search'] = 							"search";
$lang['href_channels'] =						"Channels";
$lang['href_unrecommend_this'] =				"Remove tip";
$lang['href_watch_this'] =						"Mark this";
$lang['href_recommend_this'] =					"Tip this";
$lang['href_unwatch_this'] =					"Remove mark";


// MENU
$lang['menu_events'] = 							"find events to attend";
$lang['menu_tasks'] = 							"find stuff to do";
$lang['menu_schedule'] = 						"my schedule";


//META TAGS (this will appear in search engines like google)
$lang['meta_Description'] =						""; //add in a description for your node
$lang['meta_keywords'] = 						""; //add in up to 25 keywords (barnraiser, nodeX, place)
$lang['meta_OriginalPublicationDate'] =			"";//YYYY/MM/DD // //add in a publication date


//BODY TEXT
$lang['txt_page_title'] = 						"barnraiser &#47; aroundme &#47; demo";
$lang['txt_groups'] = 							"groups";
$lang['txt_messaging'] = 						"messaging";
$lang['txt_splash'] = 							"splash";
$lang['txt_me'] = 								"me";
$lang['txt_sn'] = 								"social network";
$lang['txt_schedule'] = 						"events and tasks";
$lang['txt_print_view'] = 						"print version";
$lang['txt_print_view_comments'] = 				"print version (with comments)";
$lang['txt_strap'] = 							"This <a href=\"http://www.fsf.org/\">free software</a> is created and maintained by <a href=\"http://www.barnraiser.org/\">Barnraiser</a>. We are dedicated to giving people the tools they need to share knowledge and further society through social software. Please consider supporting us.";

?>
